% Author: Robert Grimm robert.grimm@cs.fau.de
% Pattern Recognition Lab, FAU Erlangen-Nuremberg, Erlangen, Germany
% Last change:  09.05.2012

function [kSamples] = getDynaSamples(baseres, kPos, samplingT, aif, tacs)
% compute k-space samples 
% baseres: readout resolution
% samplingT: corresponding index (not time!) in aif/tacs for all readouts
% kPos: cell array containing sets of sampling positions (all elements of a
% cell are evaluated at the same time step). 
% kSamples: corresponding cell array of k-space samples

	additionalGeometry = [ ; ... 
		0.008,0.1,0.35,-0.25,-10,0.3,2;... %artery
		0.02,0.02,0.05,-0.15,0,0.3,2;... %artery    
		0.04,0.04,-0.4,-0.42,0,0.05,3;... %healthy tissue
		0.04,0.04,0.5,-0.42,0,0.05,4;... %pathological tissue
	];
	
	M = [defaultSL(); additionalGeometry];

	% columns 1,2
	% columns 2,3
	% column 5          rotation angle (degrees)
	% columns 6         
	% column 7          indicator : 0 for standard geometry, 1: artery, 2: healthy, 3: pathological tissue

	kSamples = [];

	if numel(kPos) ~= numel(samplingT)
	  error('dynaSL:getDynaSamples:invalidKpos', 'Number of cell elements in kPos and samplingT does not match\n');
	end


    for t=1:numel(kPos)
	% update model
    % TODO: why is baseres needed in computeValue?
        Mt = updateM(M, aif, tacs(1,:), tacs(2,:), samplingT{t});
        kSamples{t}=computeValue(baseres,Mt,[kPos{t}(1,:);kPos{t}(2,:)]) ;            
    end

end 



% fixme: C0 * (1+x)???
% t: INDEX in time curve
function [ Mt ] = updateM(M, tacsArtery, tacsHealthy, tacsPatho, t)
    Mt = M;
    if t > numel(tacsArtery)
        t = numel(tacsArtery);
    end

    for y=1:size(Mt,1)
        if Mt(y,end)==2
            Mt(y,end-1) = Mt(y,end-1) *(1+tacsArtery(t));        
        elseif Mt(y,end)==3
            Mt(y,end-1) = Mt(y,end-1) *(1+tacsHealthy(t));
        elseif Mt(y,end)==4
            Mt(y,end-1) = Mt(y,end-1) *(1+tacsPatho(t));
        end
        Mt(y,end) = 0;
    end    
end