function value = ellipseValue(pos,a,b,center,deg,density)
% ELLIPSEVALUE computes the value of an ellipse in the k-space
% VALUE=ELLIPSEVALUE(POS,A,B,CENTER,DEG,DENSITY)
% Input: POS: absolut 2d Position in the k-space
%
%        A: Halfaxis of the ellipse in x-direction relativ (0,...,1)
%
%        B: Halfaxis of the ellipse in y-direction relativ (0,...,1)
%
%        CENTER: Ellipse center as relativ (-1,...,1) 2d vector
%
%        DEG: Rotationangle in degree
%
%        DENSITIVITY: Densitivity of the ellipse
%
% Output: VALUE: The contribution of the ellipse in the k-space at position
%                POS
%
% Author: Johannes Churt

a=a*pi;
b=b*pi;
deg=deg*pi/180;

%Rotation
rotpos=rotation(pos,deg);

%Calculations with bessel function of first kind
t=sqrt((a*rotpos(1,:)).^2+(b*rotpos(2,:)).^2);
value=a*b*besselj(1,t)./t;
value(isnan(value))=a*b/2;

%Translation and scaling
value=density*value.*exp(-1i*pi*(center'*pos));
end
