% Author: Robert Grimm robert.grimm@cs.fau.de
% Pattern Recognition Lab, FAU Erlangen-Nuremberg, Erlangen, Germany
% Last change:  09.05.2012

function [ samples, angles ] = sampleRadial( baseres, nSpokes, perfusionT0, perfusionTime, samplingT0, samplingTend, reordering, aifModel, doOversampling )
%SAMPLERADIAL compute radial samples
%   baseres: resolution
%   nSpokes: number of radial spokes
%   perfusionTime: time of simulated perfusion process
%   samplingT0-samplingTend: sampling time
%   reordering: 'golden' or 'incremental'
%   aifModel: 'Parker' or 'Weinmann', or user-defined aif
% optional: doOversampling: add 2x readout oversampling (default: true)

    if nargin==4
        doOversampling = true;  
    end
  
    if doOversampling
        baseres = baseres*2;
        deltaK = 0.5;
    else
        deltaK = 1.0;
    end
    
    [kx,ky, angles]=computeRadialTrajectory(reordering,baseres,nSpokes, deltaK);
   
    for i=1:nSpokes
      kxi = kx(i, :);
      kyi = ky(i, :);
      kPos{i}(1,:) = kxi(:);
      kPos{i}(2,:) = kyi(:);
    end


    % generate curves and convert to signal intensities
    tissues = tissuePresets(0);
    [aif, tacs, tvec] = generateCurves(aifModel, tissues, perfusionTime, perfusionT0);


    % compute readout times (discretized at uniform intervals of TR)
    tReadout = linspace(samplingT0, samplingTend, nSpokes);   % unit: [s]
    samplingT = cell([1, nSpokes]);
    tvecIdx = 1;
    for i=1:nSpokes
        while tvec(tvecIdx) < tReadout(i)
            tvecIdx = tvecIdx + 1;
        end
        samplingT{i} = tvecIdx;  % corresponding _indices_ into tvec / aif and tacs       
    end

    % evaluate phantom
    samples = getDynaSamples(baseres, kPos, samplingT, aif, tacs);
end
