% Author: Robert Grimm robert.grimm@cs.fau.de
% Pattern Recognition Lab, FAU Erlangen-Nuremberg, Erlangen, Germany
% Last change:  09.05.2012

function tissues = tissuePresets(preset)
% TISSUEPRESETS load presets for Ktrans / ve / kep
% This file contains some example tissue characteristics found in various literature.
% parameters:
% @preset  number of the preset to load
% returns:
% @tissues set of perfusion parameters

if (preset==0)
    Ktrans = [0.88, 0.26]/60 % unit: 1/min
    ve = [143, 36]/100;           % unit: %
    kep = Ktrans ./ ve; 
elseif (preset==1)
    Ktrans = [0.88, 0.63, 0.51, 0.26]/60 % unit: 1/min
    ve = [143, 96, 76, 36]/100;           % unit: %
    kep = Ktrans ./ ve;
elseif (preset==2)
    Ktrans = [ 0.05, 0.1, 0.2]/60;
    ve = [ 10, 10, 10]/100;
    kep = Ktrans ./ ve;
elseif (preset==3)
    Ktrans = [ 0.1, 0.1, 0.1]/60;
    ve = [ 10, 20, 40 ] /100;    
    kep = Ktrans ./ ve;
elseif (preset==4)
    Ktrans = [0.1, 0.2, 0.4]/60 ;
    kep = [ 2, 2, 2 ] /60  ;
    ve = Ktrans ./ kep;
elseif (preset==5)
    Ktrans = [0.135, 0.361]/60;
    ve = [47, 49]/100;
    kep = Ktrans ./ ve;
end

vp = zeros(size(ve));


tissues.Ktrans = Ktrans;
tissues.ve = ve;
tissues.kep = kep;
tissues.vp = vp;

end